@@ -20,7 +20,7 @@
 */
 
 #include "ksharedconfig.h"
-#include "kconfigbackend.h"
+#include "kconfigbackend_p.h"
 #include "kconfiggroup.h"
 #include "kconfig_p.h"
 #include <QCoreApplication>
@@ -87,10 +87,10 @@ KSharedConfigPtr KSharedConfig::openConfig(const QString &_fileName,
     if (!list->wasTestModeEnabled && QStandardPaths::isTestModeEnabled()) {
         list->wasTestModeEnabled = true;
         list->clear();
-        list->mainConfig = Q_NULLPTR;
+        list->mainConfig = nullptr;
     }
 
-    foreach (auto cfg, *static_cast<const GlobalSharedConfigList*>(list)) {
+    for (auto cfg :  qAsConst(*list)) {
         if (cfg->name() == fileName &&
                 cfg->d_ptr->openFlags == flags &&
                 cfg->locationType() == resType
@@ -109,8 +109,8 @@ KSharedConfigPtr KSharedConfig::openConfig(const QString &_fileName,
         static bool userWarned = false;
         if (isMainThread && !userWarned) {
             userWarned = true;
-            QByteArray readOnly = qgetenv("KDE_HOME_READONLY");
-            if (readOnly.isEmpty() && QCoreApplication::applicationName() != QLatin1String("kdialog")) {
+            const bool isReadOnly = qEnvironmentVariableIsEmpty("KDE_HOME_READONLY");
+            if (isReadOnly && QCoreApplication::applicationName() != QLatin1String("kdialog")) {
                 if (ptr->group("General").readEntry(QStringLiteral("warn_unwritable_config"), true)) {
                     ptr->isConfigWritable(true);
                 }
